// FILE: bbox.c
//
// main routine for BBOX program
//		creates a cube that is the bounding box of the given object
//
// Created by
// Jerry Isdale
// Isdale Engineering
// 4053 Beethoven St.
// Los Angeles, CA, 90066
//
// This code is public domain
//

#include <dir.h>
#include <dos.h>
#include <iegeom.h>

extern int errno;
char *pathname;
char progname[MAXFILE];
char tmpname[MAXPATH];

//-----------------------------------------------
void Usage(void)
{
eprintf("%s\n",pathname);
eprintf( "\
   Create a bounding box object that has the same size and\n\
   location of the input object.\n");

	eprintf("Usage: %s infile outfile\n",progname);
   exit(0);
}

//-----------------------------------------------
void main( int argc, char *argv[])
{
   pIeObject oop = NULL;
   pIeObject iop = NULL;
   char infile[MAXPATH];
   char outfile[MAXPATH];
   int inflag = FALSE;

	Point max, min;


	infile[0] = NULL;
	outfile[0] = NULL;

   pathname = *argv++;
	strlwr(pathname);
	fnsplit(pathname,tmpname,tmpname, progname, tmpname);

	// set error reporting to stdout
	eopenf(NULL);

   argc--;
	if (argc == 0)
		Usage();
	if (strcmp(*argv,"-") == 0)
		Usage();

	while (argc > 0) 
	{
	   if (argv[0][0] == '-') 
		{
		 	Usage();
	   } else if (inflag) 
		{
		   strcpy(outfile,argv[0]);
		   argc--; argv++;
		} else 
		{
			strcpy( infile, argv[0]);
			argc--; argv++;
			inflag = TRUE;
	   }
   }

	if (!inflag)
		Usage();
	if (!outfile[0])
	{
		eprintf("%s: missing output file\n", progname);
		exit(1);
	}

	eprintf( "Reading from %s\n", infile);
	eprintf( "Output to %s\n", outfile);

//-----------------------------------------------
	iop = ieg_ReadPLG( infile);
	if (!iop)
	{
		eprintf( "Error Reading input file %s\n", infile);
		return;
	}

	eprintf("Input Object contains %d points and %d faces\n", 
		ieg_NumPoints(iop), ieg_NumPolys(iop));

	ieg_BBox(iop, &min, &max);

	eprintf("   BBox coords:\n\tMax %g %g %g\n\tMin %g %g %g\n",
			max.x, max.y, max.z,	min.x, min.y, min.z);

	oop = ieg_Cube (min, max);
	eprintf("Output Object contains %d points and %d faces\n", 
		ieg_NumPoints(oop), ieg_NumPolys(oop));

//-----------------------------------------------
	ieg_WritePLG ( oop, outfile, 1.0, TRUE);
}

